@@ -7,17 +7,18 @@ using InteractiveUtils, Test
 @testset "NonlinearSolveBase.jl" begin
     @testset "Aqua" begin
         using Aqua, NonlinearSolveBase
+        using NonlinearSolveBase: AbstractNonlinearProblem, NonlinearProblem
 
         Aqua.test_all(
             NonlinearSolveBase; piracies = false, ambiguities = false, stale_deps = false
         )
         Aqua.test_stale_deps(NonlinearSolveBase; ignore = [:TimerOutputs])
-        Aqua.test_piracies(NonlinearSolveBase)
+        Aqua.test_piracies(NonlinearSolveBase, treat_as_own = [AbstractNonlinearProblem, NonlinearProblem])
         Aqua.test_ambiguities(NonlinearSolveBase; recursive = false)
     end
 
     @testset "Explicit Imports" begin
-        import ForwardDiff, SparseArrays, DiffEqBase
+        import ForwardDiff, SparseArrays
         using ExplicitImports, NonlinearSolveBase
 
         @test check_no_implicit_imports(NonlinearSolveBase; skip = (Base, Core)) === nothing
@@ -33,4 +34,20 @@ using InteractiveUtils, Test
 
         @test NonlinearSolveBase.Utils.faster_vcat(b, d) == vcat(sparse(b), d)
     end
+
+    @testset "Termination Conditions" begin
+        using NonlinearSolveBase, SciMLBase
+        @testset "reinit! with AbsTerminationMode" begin
+            mode = NonlinearSolveBase.AbsTerminationMode()
+            u_unaliased = nothing
+            T = Float64
+            cache = NonlinearSolveBase.NonlinearTerminationModeCache(
+                u_unaliased, SciMLBase.ReturnCode.Default, 1e-8, 1e-8, Inf, mode,
+                nothing, nothing, 0, nothing, nothing, nothing, nothing, nothing, false
+            )
+            du = [1.0, 1.0]
+            u = [1.1, 1.1]
+            @test_nowarn SciMLBase.reinit!(cache, du, u)
+        end
+    end
 end
